==> jc-1.4.0.tar.gz: java/security/cert/CertPath__24CertPathRep.h <==
// public class java.security.cert.CertPath$CertPathRep

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 53471f36772e0c85 java_security_cert_CertPath__24CertPathRep

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_CertPath__24CertPathRep_H_
#define _JC_java_security_cert_CertPath__24CertPathRep_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_cert_CertPath__24CertPathRep$sub_refs	_jc_java_security_cert_CertPath__24CertPathRep$sub_refs;
typedef struct _jc_java_security_cert_CertPath__24CertPathRep$sub_nonrefs	_jc_java_security_cert_CertPath__24CertPathRep$sub_nonrefs;
typedef struct _jc_java_security_cert_CertPath__24CertPathRep$refs	_jc_java_security_cert_CertPath__24CertPathRep$refs;
typedef struct _jc_java_security_cert_CertPath__24CertPathRep$nonrefs	_jc_java_security_cert_CertPath__24CertPathRep$nonrefs;
typedef struct _jc_java_security_cert_CertPath__24CertPathRep$object	_jc_java_security_cert_CertPath__24CertPathRep$object;

typedef struct _jc_java_security_cert_CertPath__24CertPathRep$fields_struct	_jc_java_security_cert_CertPath__24CertPathRep$fields_struct;
typedef const struct _jc_java_security_cert_CertPath__24CertPathRep$vmethods	_jc_java_security_cert_CertPath__24CertPathRep$vmethods;
typedef const struct _jc_java_security_cert_CertPath__24CertPathRep$vtable	_jc_java_security_cert_CertPath__24CertPathRep$vtable;
typedef const struct _jc_java_security_cert_CertPath__24CertPathRep$vtype	_jc_java_security_cert_CertPath__24CertPathRep$vtype;

// Class fields structure
struct _jc_java_security_cert_CertPath__24CertPathRep$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_cert_CertPath__24CertPathRep$fields_struct _jc_java_security_cert_CertPath__24CertPathRep$class_fields;

// Constructors
extern void _jc_java_security_cert_CertPath__24CertPathRep$method$_init$8978305ea064370f(_jc_env *, struct _jc_java_security_cert_CertPath__24CertPathRep$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_cert_CertPath__24CertPathRep$method$readResolve$3c2bccd3a831d3ae(_jc_env *, struct _jc_java_security_cert_CertPath__24CertPathRep$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CertPath__24CertPathRep$method_info$readResolve$3c2bccd3a831d3ae;

// Virtual methods structure
struct _jc_java_security_cert_CertPath__24CertPathRep$vmethods {
	struct _jc_java_lang_Object$object	*(*readResolve$3c2bccd3a831d3ae)(_jc_env *, struct _jc_java_security_cert_CertPath__24CertPathRep$object *);
};

// Vtable
struct _jc_java_security_cert_CertPath__24CertPathRep$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CertPath__24CertPathRep$vmethods	java_security_cert_CertPath__24CertPathRep;
};

// Vtype
struct _jc_java_security_cert_CertPath__24CertPathRep$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertPath__24CertPathRep$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertPath__24CertPathRep$sub_refs {
	struct _jc_java_lang_String$object	*type;
	_jc_byte_array	*data;
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertPath__24CertPathRep$refs {
    _jc_java_security_cert_CertPath__24CertPathRep$sub_refs	java_security_cert_CertPath__24CertPathRep;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertPath__24CertPathRep$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertPath__24CertPathRep$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CertPath__24CertPathRep$sub_nonrefs	java_security_cert_CertPath__24CertPathRep;
};

// Object instance structure
struct _jc_java_security_cert_CertPath__24CertPathRep$object {
	_jc_java_security_cert_CertPath__24CertPathRep$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertPath__24CertPathRep$vtype	*vtype;
	_jc_java_security_cert_CertPath__24CertPathRep$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertPath__24CertPathRep$vtype _jc_java_security_cert_CertPath__24CertPathRep$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertPath__24CertPathRep, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertPath__24CertPathRep$class_object;

#endif	/* _JC_java_security_cert_CertPath__24CertPathRep_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/CertPath__24CertPathRep.h <==
// public class java.security.cert.CertPath$CertPathRep

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 53471f36772e0c85 java_security_cert_CertPath__24CertPathRep

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_CertPath__24CertPathRep_H_
#define _JC_java_security_cert_CertPath__24CertPathRep_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_cert_CertPath__24CertPathRep$sub_refs	_jc_java_security_cert_CertPath__24CertPathRep$sub_refs;
typedef struct _jc_java_security_cert_CertPath__24CertPathRep$sub_nonrefs	_jc_java_security_cert_CertPath__24CertPathRep$sub_nonrefs;
typedef struct _jc_java_security_cert_CertPath__24CertPathRep$refs	_jc_java_security_cert_CertPath__24CertPathRep$refs;
typedef struct _jc_java_security_cert_CertPath__24CertPathRep$nonrefs	_jc_java_security_cert_CertPath__24CertPathRep$nonrefs;
typedef struct _jc_java_security_cert_CertPath__24CertPathRep$object	_jc_java_security_cert_CertPath__24CertPathRep$object;

typedef struct _jc_java_security_cert_CertPath__24CertPathRep$fields_struct	_jc_java_security_cert_CertPath__24CertPathRep$fields_struct;
typedef const struct _jc_java_security_cert_CertPath__24CertPathRep$vmethods	_jc_java_security_cert_CertPath__24CertPathRep$vmethods;
typedef const struct _jc_java_security_cert_CertPath__24CertPathRep$vtable	_jc_java_security_cert_CertPath__24CertPathRep$vtable;
typedef const struct _jc_java_security_cert_CertPath__24CertPathRep$vtype	_jc_java_security_cert_CertPath__24CertPathRep$vtype;

// Class fields structure
struct _jc_java_security_cert_CertPath__24CertPathRep$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_security_cert_CertPath__24CertPathRep$fields_struct _jc_java_security_cert_CertPath__24CertPathRep$class_fields;

// Constructors
extern void _jc_java_security_cert_CertPath__24CertPathRep$method$_init$8978305ea064370f(_jc_env *, struct _jc_java_security_cert_CertPath__24CertPathRep$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_cert_CertPath__24CertPathRep$method$readResolve$3c2bccd3a831d3ae(_jc_env *, struct _jc_java_security_cert_CertPath__24CertPathRep$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CertPath__24CertPathRep$method_info$readResolve$3c2bccd3a831d3ae;

// Virtual methods structure
struct _jc_java_security_cert_CertPath__24CertPathRep$vmethods {
	struct _jc_java_lang_Object$object	*(*readResolve$3c2bccd3a831d3ae)(_jc_env *, struct _jc_java_security_cert_CertPath__24CertPathRep$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_CertPath__24CertPathRep$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CertPath__24CertPathRep$vmethods	java_security_cert_CertPath__24CertPathRep;
};

// Vtype
struct _jc_java_security_cert_CertPath__24CertPathRep$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertPath__24CertPathRep$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertPath__24CertPathRep$sub_refs {
	struct _jc_java_lang_String$object	*type;
	_jc_byte_array	*data;
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertPath__24CertPathRep$refs {
    _jc_java_security_cert_CertPath__24CertPathRep$sub_refs	java_security_cert_CertPath__24CertPathRep;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertPath__24CertPathRep$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertPath__24CertPathRep$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CertPath__24CertPathRep$sub_nonrefs	java_security_cert_CertPath__24CertPathRep;
};

// Object instance structure
struct _jc_java_security_cert_CertPath__24CertPathRep$object {
	_jc_java_security_cert_CertPath__24CertPathRep$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertPath__24CertPathRep$vtype	*vtype;
	_jc_java_security_cert_CertPath__24CertPathRep$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertPath__24CertPathRep$vtype _jc_java_security_cert_CertPath__24CertPathRep$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertPath__24CertPathRep, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertPath__24CertPathRep$class_object;

#endif	/* _JC_java_security_cert_CertPath__24CertPathRep_H_ */
